@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.06';
+our $VERSION = '5.07';
 
 URPM->bootstrap($VERSION);
 
@@ -868,6 +868,7 @@ It's usually the $urpm object.
 Recognized options are:
 
     callback_close  => sub { ... }
+    callback_elem   => sub { ... }
     callback_error  => sub { ... }
     callback_inst   => sub { ... }
     callback_open   => sub { ... }
@@ -893,7 +894,7 @@ C<$cb_type> is one of 'open' or 'close'.
 
 Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>, C<pkg_name>)
 
-C<$cb_type> is one of 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
+C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
 
 The purpose of those callbacks is to report progress (the two last parameters (C<$amount> & C<$total>) enable to compute progress percentage).
